import React from 'react'
import { Service } from '../../Utils/HTTP'
import { Question } from '../../Components/Test/Cleaver/Question.jsx'
import { Box,Button, LinearProgress  } from '@mui/material'
import { useSelector } from 'react-redux';
import { useParams } from 'react-router-dom'
import toast, { Toaster } from 'react-hot-toast';


function LinearProgressWithLabel(props) {
  return (
    <Box sx={{ display: 'flex', alignItems: 'center' }}>
      <Box sx={{ width: '100%', mr: 0 }}>
        <LinearProgress variant="determinate" {...props} />
      </Box>
    </Box>
  );
}

export function Cleaver() {

  let { id } = useParams();
  const auth = useSelector((state) => state.token.token);
  const cleaver = useSelector((state) => state.cleaver);

  const [totalRespondidas, setRespondidas] = React.useState([]);
  const [totalPreguntas, setPreguntas] = React.useState([]);
  const [current, setCurrent] = React.useState(0);
  const [progress, setProgress] = React.useState(0);

  const BadQuestion = () => toast.error("Escoge una respuesta en cada columna") 
  //toast("Escoge una respuesta en cada columna",{ icon : '⚠️' });
  const CalculateProgress = () => {
    let total_preguntas = totalPreguntas.length + totalRespondidas.length
    let x = totalRespondidas.length *100 / (total_preguntas)
    setProgress(x.toFixed(2))
  }

  React.useEffect(() => {
    let rest = new Service(`/prueba/findid/${id}`)
    rest.get(auth.token)
      .then(({ data }) => {
        console.log(data.questions)
        setPreguntas(data.questions)
        setRespondidas(data.questions.slice(0,1))
        setCurrent(0)
      }).catch(console.log)
  }, [id,auth]);

  const saveRespones = () => {
    console.log("guardando las respuestas")
  }

  const handleAddQuestion = () => {
    let currentAnswer  = totalRespondidas[totalRespondidas.length - 1];
    let current_resp = cleaver.responses[currentAnswer.id];

    if(!current_resp){
      return BadQuestion();
    }
    if(parseInt( current_resp.A ) ===0 || parseInt( current_resp.B ) === 0){
      return BadQuestion();
    }
    const nextHiddenItem = totalPreguntas.filter(({id}) => id !== currentAnswer.id );
    if (nextHiddenItem) {
      setPreguntas(nextHiddenItem);
      setCurrent(current+1);
      let temp = nextHiddenItem.shift()
      setRespondidas([...totalRespondidas,temp]);
    }
    CalculateProgress()
  };

  const handleRemoveQuestion = () => {
    let ultimaRespondida = totalRespondidas[totalRespondidas.length - 1];
    setPreguntas([ultimaRespondida,...totalPreguntas]);
    let current_without_last = totalRespondidas.filter(({id}) => id !== ultimaRespondida.id);
    setRespondidas([...current_without_last]);
    setCurrent(current - 1 )
    CalculateProgress()
  }



  return (
    <div>
    <div className="content-section question">
      <div style={{width:'60%', marginBottom : 35}}>
        <LinearProgressWithLabel value={progress ? parseInt(progress) : 0 } />
      </div>
      <Box className="question_body">
        {totalRespondidas.map((item,i) => (
          <Question 
            key={item.id} 
            id={item.id} 
            quiz={item} 
            index={i} 
            current={current} 
            />)
        )}
      </Box>

      {
      totalPreguntas.length > 0 ?
          (
            <div className="question_btn">
              <Button
                className="nextquestion_btn"
                sx={{ backgroundColor: 'var(--main)' }}
                variant="contained"
                disabled={totalRespondidas.length <= 1}
                onClick={handleRemoveQuestion}
              >
                Anterior
              </Button>
              <Button
                className="nextquestion_btn"
                sx={{ backgroundColor: 'var(--main)' }}
                variant="contained"
                disabled={totalPreguntas.length <= 0}
                onClick={handleAddQuestion}
              >
                Siguiente
              </Button>
            </div>
          ) : (

            <div className="question_btn">
              <Button
                className="nextquestion_btn"
                sx={{ backgroundColor: 'var(--main)' }}
                variant="contained"
                onClick={saveRespones}
              >
                Guardar
              </Button>
            </div>
          )
      
      }

      <Toaster position="bottom-right" />

    </div>
    </div>
  )

}


